aboutsummaryrefslogtreecommitdiffstats
diff options
context:
space:
mode:
author Eric Hameleers <alien@slackware.com>2023-12-24 16:13:54 +0100
committer Eric Hameleers <alien@slackware.com>2023-12-24 16:13:54 +0100
commit85e91fce553600b3e71fec4f7ee9ae8da7a5bc1f (patch)
tree4caa163f746ffbee141b47b649393e23e56134e5
parent1aebadde8aca3349a59315b1e42c0c2f66b164b2 (diff)
downloadliveslak-85e91fce553600b3e71fec4f7ee9ae8da7a5bc1f.tar.gz
liveslak-85e91fce553600b3e71fec4f7ee9ae8da7a5bc1f.tar.xz
Generalize where useful: Plasma5 or Plasma6 are all Plasma
-rwxr-xr-xmake_slackware_live.sh25
1 files changed, 13 insertions, 12 deletions
diff --git a/make_slackware_live.sh b/make_slackware_live.sh
index 880feb7..87b1d44 100755
--- a/make_slackware_live.sh
+++ b/make_slackware_live.sh
@@ -2585,14 +2585,14 @@ EOT
fi # End KDE4
-# Only configure for Plasma5 if it is actually installed:
-if [ -d ${LIVE_ROOTDIR}/usr/lib${DIRSUFFIX}/kf5 ]; then
+# Only configure for KDE Plasma if it is actually installed:
+if [ -d ${LIVE_ROOTDIR}/usr/lib${DIRSUFFIX}/libexec/kf5 ] || [ -d ${LIVE_ROOTDIR}/usr/lib${DIRSUFFIX}/libexec/kf6 ] ; then
# -------------------------------------------------------------------------- #
- echo "-- Configuring Plasma5."
+ echo "-- Configuring Plasma Desktop."
# -------------------------------------------------------------------------- #
# This section is for any Plasma5 based variant.
# Install a custom login/desktop/lock background if an image is present:
plasma5_custom_bg
@@ -2647,8 +2647,8 @@ EOT
super-user-command=sudo
KDESU_EOF
# For the above to work in KDE5 with newer versions of sudo (since 2022),
# we need the following also. KDE5 fixed this in git on 04-aug-2023, see
# https://bugs.kde.org/show_bug.cgi?id=452532 but it does not hurt to have
# it here, and it helps to support older KDE releases:
if [ -x ${LIVE_ROOTDIR}/usr/lib*/libexec/kf5/kdesu_stub ]; then
@@ -2721,8 +2721,9 @@ Zonetab=/usr/share/zoneinfo/zone.tab
EOTZ
# Make sure that Plasma and SDDM work on older GPUs,
- # by forcing Qt5 to use software GL rendering:
- cat <<"EOGL" >> ${LIVE_ROOTDIR}/usr/share/sddm/scripts/Xsetup
+ # by forcing Qt to use software GL rendering:
+ if ! grep -q QT_XCB_FORCE_SOFTWARE_OPENGL ${LIVE_ROOTDIR}/usr/share/sddm/scripts/Xsetup ; then
+ cat <<"EOGL" >> ${LIVE_ROOTDIR}/usr/share/sddm/scripts/Xsetup
OPENGL_VERSION=$(LANG=C glxinfo |grep '^OpenGL version string: ' |head -n 1 |sed -e 's/^OpenGL version string: \([0-9]\).*$/\1/g')
if [ "$OPENGL_VERSION" -lt 2 ]; then
@@ -2735,7 +2736,7 @@ EOGL
# Workaround a bug where SDDM does not always use the configured keymap:
echo "setxkbmap" >> ${LIVE_ROOTDIR}/usr/share/sddm/scripts/Xsetup
# Do not show the blueman applet, Plasma5 has its own BlueTooth widget:
echo "NotShowIn=KDE;" >> ${LIVE_ROOTDIR}/etc/xdg/autostart/blueman.desktop
# Set QtWebkit as the Konqueror rendering engine if available:
@@ -2753,14 +2754,14 @@ EOT
mkdir -p ${LIVE_ROOTDIR}/etc/profile.d
cat <<EOT > ${LIVE_ROOTDIR}/etc/profile.d/kwayland.sh
#!/bin/sh
-# Force the usage of XCB platform on Qt5 applications:
+# Force the usage of XCB platform on Qt applications:
export QT_QPA_PLATFORM=xcb
# Force the usage of X11 platform for GDK applications:
export GDK_BACKEND=x11
EOT
cat <<EOT > ${LIVE_ROOTDIR}/etc/profile.d/kwayland.csh
#!/bin/csh
-# Force the usage of XCB platform on Qt5 applications:
+# Force the usage of XCB platform on Qt applications:
setenv QT_QPA_PLATFORM xcb
# Force the usage of X11 platform for GDK applications:
setenv GDK_BACKEND x11
@@ -2799,7 +2800,7 @@ EOT
rm -rf ${LIVE_ROOTDIR}/usr/share/wayland-sessions
fi
-fi # End Plasma5
+fi # End Plasma
if [ "$LIVEDE" = "DLACK" ]; then
@@ -2585,14 +2585,14 @@ EOT
# -------------------------------------------------------------------------- #
- # This section is for any Plasma5 based variant.
+ # This section is for any Plasma based variant.
# Install a custom login/desktop/lock background if an image is present:
plasma5_custom_bg
@@ -2647,8 +2647,8 @@ EOT
super-user-command=sudo
KDESU_EOF
- # For the above to work in KDE5 with newer versions of sudo (since 2022),
- # we need the following also. KDE5 fixed this in git on 04-aug-2023, see
+ # For the above to work in Plasma with newer versions of sudo (since 2022),
+ # we need the following also. KDE fixed this in git on 04-aug-2023, see
# https://bugs.kde.org/show_bug.cgi?id=452532 but it does not hurt to have
# it here, and it helps to support older KDE releases:
@@ -2735,7 +2736,7 @@ EOGL
# Workaround a bug where SDDM does not always use the configured keymap:
echo "setxkbmap" >> ${LIVE_ROOTDIR}/usr/share/sddm/scripts/Xsetup
- # Do not show the blueman applet, Plasma5 has its own BlueTooth widget:
+ # Do not show the blueman applet, Plasma has its own BlueTooth widget:
echo "NotShowIn=KDE;" >> ${LIVE_ROOTDIR}/etc/xdg/autostart/blueman.desktop
# Set QtWebkit as the Konqueror rendering engine if available: